<?php
// Añadir un campo personalizado en la página de producto
function calculadora_cajas_m2_custom_field() {
    global $post;
    $value = get_post_meta($post->ID, '_m2_por_caja', true);
    echo '<div class="options_group">';
    woocommerce_wp_text_input([
        'id' => '_m2_por_caja',
        'label' => __('Metros cuadrados por caja', 'calculadora-cajas-m2'),
        'placeholder' => 'Ingresa cuántos m2 cubre una caja',
        'desc_tip' => 'true',
        'description' => __('Cuántos metros cuadrados cubre una caja.', 'calculadora-cajas-m2'),
        'type' => 'text',
        'custom_attributes' => [
            'pattern' => '[0-9]*[.,]?[0-9]+', // Permitir números con coma o punto decimal
        ]
    ]);
    echo '</div>';
}
add_action('woocommerce_product_options_pricing', 'calculadora_cajas_m2_custom_field');

// Guardar el valor de m2 por caja
function calculadora_cajas_m2_save_custom_field($post_id) {
    if (isset($_POST['_m2_por_caja'])) {
        $m2_por_caja = str_replace(',', '.', $_POST['_m2_por_caja']); // Cambiar coma por punto si es necesario
        update_post_meta($post_id, '_m2_por_caja', esc_attr($m2_por_caja));
    }
}
add_action('woocommerce_process_product_meta', 'calculadora_cajas_m2_save_custom_field');

// Exportar el campo personalizado al CSV
add_filter('woocommerce_product_export_column_names', 'agregar_campo_personalizado_exportacion');
add_filter('woocommerce_product_export_product_default_columns', 'agregar_campo_personalizado_exportacion');

function agregar_campo_personalizado_exportacion($columns) {
    $columns['_m2_por_caja'] = 'Metros cuadrados por caja'; 
    return $columns;
}

add_filter('woocommerce_product_export_product_column__m2_por_caja', 'exportar_campo_personalizado', 10, 2);

function exportar_campo_personalizado($value, $product) {
    $value = get_post_meta($product->get_id(), '_m2_por_caja', true);
    return $value ? $value : ''; 
}

// Importar el campo personalizado desde CSV
add_filter('woocommerce_csv_product_import_mapping_options', 'm2_por_caja_import_mapping_options');
function m2_por_caja_import_mapping_options($options) {
    $options['_m2_por_caja'] = __('Metros cuadrados por caja', 'calculadora-cajas-m2'); 
    return $options;
}

add_filter('woocommerce_csv_product_import_mapping_default_columns', 'm2_por_caja_default_columns');
function m2_por_caja_default_columns($columns) {
    $columns['Metros cuadrados por caja'] = '_m2_por_caja'; 
    return $columns;
}

// Guardar el valor importado
add_action('woocommerce_product_import_before_save_product', 'importar_campo_personalizado', 10, 2);

function importar_campo_personalizado($product, $data) {
    if (isset($data['_m2_por_caja']) && $data['_m2_por_caja'] !== '') {
        $value = str_replace(',', '.', $data['_m2_por_caja']); // Normalizar formato
        $product->update_meta_data('_m2_por_caja', $value);
    }
}
?>
