<?php
/**
 * Plugin Name: Calculadora Cajas por m2
 * Description: Calculadora que permite calcular cuántas cajas necesitas según los m2 a cubrir.
 * Version: 1.2.4
 * Author: Fer S
 * Author URI: https://fersosa.com/
 */

if (!defined('ABSPATH')) {
    exit; // Evitar acceso directo.
}

// Incluir archivos necesarios
include_once plugin_dir_path(__FILE__) . 'admin/admin-settings.php';
include_once plugin_dir_path(__FILE__) . 'includes/frontend-calculator.php';

// Activar los estilos
function calculadora_cajas_m2_enqueue_styles() {
    wp_enqueue_style('calculadora-style', plugin_dir_url(__FILE__) . 'assets/style.css');
}
add_action('wp_enqueue_scripts', 'calculadora_cajas_m2_enqueue_styles');

// Crear un menú en el admin con instrucciones del shortcode
function calculadora_cajas_m2_menu() {
    add_menu_page(
        'Calculadora Cajas m2',
        'Calculadora Cajas m2',
        'manage_options',
        'calculadora-cajas-m2',
        'calculadora_cajas_m2_instrucciones',
        'dashicons-calculator',
        20
    );
}
add_action('admin_menu', 'calculadora_cajas_m2_menu');
// Instrucciones de uso
function calculadora_cajas_m2_instrucciones() {
    ?>
    <div class="wrap">
        <h1><?php _e('Calculadora Cajas por m2', 'calculadora-cajas-m2'); ?></h1>
        <p><?php _e('Para mostrar la calculadora en el frontend, usa el siguiente shortcode:', 'calculadora-cajas-m2'); ?></p>
        <code>[calculadora_m2]</code>
		<p><?php _e('Muestra el precio por metro cuadrado:', 'calculadora-cajas-m2'); ?></p>
        <code>[precio_m2]</code>
		<p><?php _e('Muestra el precio por caja:', 'calculadora-cajas-m2'); ?></p>
        <code>[precio_caja]</code>
		<p><?php _e('Muestra cuántos m² trae una caja:', 'calculadora-cajas-m2'); ?></p>
        <code>[metros_por_caja]</code>
    </div>
    <?php
}
// Añadir un script personalizado en el frontend
add_action('wp_enqueue_scripts', 'calcular_m2_por_cantidad_scripts');
function calcular_m2_por_cantidad_scripts() {
    if (is_product()) {
        wp_enqueue_script('calcular-m2-por-cantidad', plugin_dir_url(__FILE__) . 'js/calcular-m2-por-cantidad.js', array('jquery'), '1.0', true);

        // Pasar el valor del meta campo al script
        global $post;
        $m2_por_caja = get_post_meta($post->ID, '_m2_por_caja', true);
        wp_localize_script('calcular-m2-por-cantidad', 'calculadoraData', array(
            'm2_por_caja' => $m2_por_caja,
        ));
    }
}
add_shortcode('precio_m2', 'mostrar_precio_m2');
function mostrar_precio_m2() {
    global $post;

    // Obtener el precio por m²
    $product = wc_get_product($post->ID);
    $precio_por_m2 = $product->get_price();
    $m2_por_caja = get_post_meta($post->ID, '_m2_por_caja', true);

    // Mostrar solo si el campo m2_por_caja está configurado
    if ($m2_por_caja) {
        return number_format($precio_por_m2, 2);
    }

    return ''; // No mostrar nada si el campo no está configurado
}
add_shortcode('precio_caja', 'mostrar_precio_caja');
function mostrar_precio_caja() {
    global $post;

    // Obtener el precio por m² y m² por caja
    $product = wc_get_product($post->ID);
    $precio_por_m2 = $product->get_price();
    $m2_por_caja = get_post_meta($post->ID, '_m2_por_caja', true);

    // Calcular el precio por caja si el campo está configurado
    if ($m2_por_caja) {
        $precio_por_caja = $precio_por_m2 * $m2_por_caja;
        return number_format($precio_por_caja, 2);
    }

    return ''; // No mostrar nada si el campo no está configurado
}

add_shortcode('metros_por_caja', 'mostrar_metros_por_caja');
function mostrar_metros_por_caja() {
    global $post;

    // Obtener los m² por caja
    $m2_por_caja = get_post_meta($post->ID, '_m2_por_caja', true);

    // Mostrar solo si el campo está configurado
    if ($m2_por_caja) {
       return esc_html($m2_por_caja) . ' m²';
    }

    return ''; // No mostrar nada si el campo no está configurado
}

// Modificar el precio al agregar al carrito
add_filter('woocommerce_add_cart_item_data', 'ajustar_precio_por_caja', 10, 2);
function ajustar_precio_por_caja($cart_item_data, $product_id) {
    $product = wc_get_product($product_id);
    $precio_por_m2 = $product->get_price();
    $m2_por_caja = get_post_meta($product_id, '_m2_por_caja', true);

    if ($m2_por_caja) {
        // Calcular el precio por caja
        $precio_por_caja = $precio_por_m2 * $m2_por_caja;
        $cart_item_data['precio_por_caja'] = $precio_por_caja;
    }

    return $cart_item_data;
}

// Mostrar el precio por caja en el carrito
add_filter('woocommerce_cart_item_price', 'mostrar_precio_personalizado', 10, 3);
function mostrar_precio_personalizado($price, $cart_item, $cart_item_key) {
    if (isset($cart_item['precio_por_caja'])) {
        $price = wc_price($cart_item['precio_por_caja']); // Precio por caja
    }
    return $price;
}

// Calcular el subtotal usando el precio por caja
add_action('woocommerce_before_calculate_totals', 'recalcular_precio_total');
function recalcular_precio_total($cart) {
    if (is_admin() && !defined('DOING_AJAX')) return;

    foreach ($cart->get_cart() as $cart_item) {
        if (isset($cart_item['precio_por_caja'])) {
            $cart_item['data']->set_price($cart_item['precio_por_caja']);
        }
    }
}